@@ -52,7 +52,7 @@ Q_SIGNALS:
 
 protected:
     void closeEvent(QCloseEvent *e) override;
-    QDialogButtonBox *m_buttons;
+    QDialogButtonBox * m_buttons = nullptr;
 };
 
 #endif
